@@ -21,7 +21,6 @@
 
 #include "QidoRs.h"
 
-#include "StowRs.h"  // For IsXmlExpected()
 #include "Configuration.h"
 #include "DicomWebFormatter.h"
 
@@ -494,7 +493,8 @@ static void ApplyMatcher(OrthancPluginRestOutput* output,
   
   std::string wadoBase = OrthancPlugins::Configuration::GetBaseUrl(request);
 
-  OrthancPlugins::DicomWebFormatter::HttpWriter writer(output, IsXmlExpected(request));
+  OrthancPlugins::DicomWebFormatter::HttpWriter writer(
+    output, OrthancPlugins::Configuration::IsXmlExpected(request));
 
   // Fix of issue #13
   for (ResourcesAndInstances::const_iterator
