@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2018 Osimis S.A., Belgium
+ * Copyright (C) 2017-2019 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -21,10 +21,10 @@
 
 #include "WadoRs.h"
 
-#include "Dicom.h"
-#include "Plugin.h"
+#include "GdcmParsedDicomFile.h"
 
 #include <Core/Toolbox.h>
+#include <Plugins/Samples/Common/OrthancPluginCppWrapper.h>
 
 #include <memory>
 #include <list>
@@ -35,6 +35,7 @@
 #include <boost/lexical_cast.hpp>
 
 
+
 static void TokenizeAndNormalize(std::vector<std::string>& tokens,
                                  const std::string& source,
                                  char separator)
@@ -49,6 +50,17 @@ static void TokenizeAndNormalize(std::vector<std::string>& tokens,
 }
 
 
+static void RemoveSurroundingQuotes(std::string& value)
+{
+  if (!value.empty() &&
+      value[0] == '\"' &&
+      value[value.size() - 1] == '\"')
+  {
+    value = value.substr(1, value.size() - 2);
+  }  
+}
+
+
 
 static gdcm::TransferSyntax ParseTransferSyntax(const OrthancPluginHttpRequest* request)
 {
@@ -89,11 +101,13 @@ static gdcm::TransferSyntax ParseTransferSyntax(const OrthancPluginHttpRequest*
         if (parsed[0] == "type")
         {
           type = parsed[1];
+          RemoveSurroundingQuotes(type);
         }
 
         if (parsed[0] == "transfer-syntax")
         {
           transferSyntax = parsed[1];
+          RemoveSurroundingQuotes(transferSyntax);
         }
       }
 
@@ -105,9 +119,10 @@ static gdcm::TransferSyntax ParseTransferSyntax(const OrthancPluginHttpRequest*
         }
         else
         {
-          OrthancPlugins::Configuration::LogError("DICOMweb RetrieveFrames: Cannot specify a transfer syntax (" + 
-                                                  transferSyntax + ") for default Little Endian uncompressed pixel data");
-          throw Orthanc::OrthancException(Orthanc::ErrorCode_BadRequest);
+          throw Orthanc::OrthancException(
+            Orthanc::ErrorCode_BadRequest,
+            "DICOMweb RetrieveFrames: Cannot specify a transfer syntax (" + 
+            transferSyntax + ") for default Little Endian uncompressed pixel data");
         }
       }
       else
@@ -221,10 +236,10 @@ static gdcm::TransferSyntax ParseTransferSyntax(const OrthancPluginHttpRequest*
           return gdcm::TransferSyntax::JPEG2000Part2;
         }
 
-
-        OrthancPlugins::Configuration::LogError("DICOMweb RetrieveFrames: Transfer syntax \"" + 
-                                                  transferSyntax + "\" is incompatible with media type \"" + type + "\"");
-        throw Orthanc::OrthancException(Orthanc::ErrorCode_BadRequest);
+        throw Orthanc::OrthancException(
+          Orthanc::ErrorCode_BadRequest,
+          "DICOMweb RetrieveFrames: Transfer syntax \"" + 
+          transferSyntax + "\" is incompatible with media type \"" + type + "\"");
       }
     }
   }
@@ -257,8 +272,8 @@ static void ParseFrameList(std::list<unsigned int>& frames,
     int frame = boost::lexical_cast<int>(tokens[i]);
     if (frame <= 0)
     {
-      OrthancPlugins::Configuration::LogError("Invalid frame number (must be > 0): " + tokens[i]);
-      throw Orthanc::OrthancException(Orthanc::ErrorCode_ParameterOutOfRange);
+      throw Orthanc::OrthancException(Orthanc::ErrorCode_ParameterOutOfRange,
+                                      "Invalid frame number (must be > 0): " + tokens[i]);
     }
 
     frames.push_back(static_cast<unsigned int>(frame - 1));
@@ -318,7 +333,7 @@ static const char* GetMimeType(const gdcm::TransferSyntax& syntax)
 
 static void AnswerSingleFrame(OrthancPluginRestOutput* output,
                               const OrthancPluginHttpRequest* request,
-                              const OrthancPlugins::ParsedDicomFile& dicom,
+                              const OrthancPlugins::GdcmParsedDicomFile& dicom,
                               const char* frame,
                               size_t size,
                               unsigned int frameIndex)
@@ -329,9 +344,9 @@ static void AnswerSingleFrame(OrthancPluginRestOutput* output,
   std::string location = dicom.GetWadoUrl(request) + "frames/" + boost::lexical_cast<std::string>(frameIndex + 1);
   const char *keys[] = { "Content-Location" };
   const char *values[] = { location.c_str() };
-  error = OrthancPluginSendMultipartItem2(OrthancPlugins::Configuration::GetContext(), output, frame, size, 1, keys, values);
+  error = OrthancPluginSendMultipartItem2(OrthancPlugins::GetGlobalContext(), output, frame, size, 1, keys, values);
 #else
-  error = OrthancPluginSendMultipartItem(OrthancPlugins::Configuration::GetContext(), output, frame, size);
+  error = OrthancPluginSendMultipartItem(OrthancPlugins::GetGlobalContext(), output, frame, size);
 #endif
 
   if (error != OrthancPluginErrorCode_Success)
@@ -344,19 +359,25 @@ static void AnswerSingleFrame(OrthancPluginRestOutput* output,
 
 static bool AnswerFrames(OrthancPluginRestOutput* output,
                          const OrthancPluginHttpRequest* request,
-                         const OrthancPlugins::ParsedDicomFile& dicom,
+                         const OrthancPlugins::GdcmParsedDicomFile& dicom,
                          const gdcm::TransferSyntax& syntax,
                          std::list<unsigned int>& frames)
 {
-  if (!dicom.GetDataSet().FindDataElement(OrthancPlugins::DICOM_TAG_PIXEL_DATA))
+  static const gdcm::Tag DICOM_TAG_BITS_ALLOCATED(0x0028, 0x0100);
+  static const gdcm::Tag DICOM_TAG_COLUMNS(0x0028, 0x0011);
+  static const gdcm::Tag DICOM_TAG_PIXEL_DATA(0x7fe0, 0x0010);
+  static const gdcm::Tag DICOM_TAG_ROWS(0x0028, 0x0010);
+  static const gdcm::Tag DICOM_TAG_SAMPLES_PER_PIXEL(0x0028, 0x0002);
+
+  if (!dicom.GetDataSet().FindDataElement(DICOM_TAG_PIXEL_DATA))
   {
     throw Orthanc::OrthancException(Orthanc::ErrorCode_IncompatibleImageFormat);
   }
 
-  const gdcm::DataElement& pixelData = dicom.GetDataSet().GetDataElement(OrthancPlugins::DICOM_TAG_PIXEL_DATA);
+  const gdcm::DataElement& pixelData = dicom.GetDataSet().GetDataElement(DICOM_TAG_PIXEL_DATA);
   const gdcm::SequenceOfFragments* fragments = pixelData.GetSequenceOfFragments();
 
-  if (OrthancPluginStartMultipartAnswer(OrthancPlugins::Configuration::GetContext(), 
+  if (OrthancPluginStartMultipartAnswer(OrthancPlugins::GetGlobalContext(), 
                                         output, "related", GetMimeType(syntax)) != OrthancPluginErrorCode_Success)
   {
     return false;
@@ -368,16 +389,16 @@ static bool AnswerFrames(OrthancPluginRestOutput* output,
 
     if (pixelData.GetByteValue() == NULL)
     {
-      OrthancPlugins::Configuration::LogError("Image was not properly decoded");
-      throw Orthanc::OrthancException(Orthanc::ErrorCode_InternalError);      
+      throw Orthanc::OrthancException(Orthanc::ErrorCode_InternalError,
+                                      "Image was not properly decoded");
     }
 
     int width, height, bits, samplesPerPixel;
 
-    if (!dicom.GetIntegerTag(height, *dictionary_, OrthancPlugins::DICOM_TAG_ROWS) ||
-        !dicom.GetIntegerTag(width, *dictionary_, OrthancPlugins::DICOM_TAG_COLUMNS) ||
-        !dicom.GetIntegerTag(bits, *dictionary_, OrthancPlugins::DICOM_TAG_BITS_ALLOCATED) || 
-        !dicom.GetIntegerTag(samplesPerPixel, *dictionary_, OrthancPlugins::DICOM_TAG_SAMPLES_PER_PIXEL))
+    if (!dicom.GetIntegerTag(height, DICOM_TAG_ROWS) ||
+        !dicom.GetIntegerTag(width, DICOM_TAG_COLUMNS) ||
+        !dicom.GetIntegerTag(bits, DICOM_TAG_BITS_ALLOCATED) || 
+        !dicom.GetIntegerTag(samplesPerPixel, DICOM_TAG_SAMPLES_PER_PIXEL))
     {
       throw Orthanc::OrthancException(Orthanc::ErrorCode_BadFileFormat);
     }
@@ -408,9 +429,10 @@ static bool AnswerFrames(OrthancPluginRestOutput* output,
     {
       if (*frame >= framesCount)
       {
-        OrthancPlugins::Configuration::LogError("Trying to access frame number " + boost::lexical_cast<std::string>(*frame + 1) + 
-                                                " of an image with " + boost::lexical_cast<std::string>(framesCount) + " frames");
-        throw Orthanc::OrthancException(Orthanc::ErrorCode_ParameterOutOfRange);
+        throw Orthanc::OrthancException(
+          Orthanc::ErrorCode_ParameterOutOfRange,
+          "Trying to access frame number " + boost::lexical_cast<std::string>(*frame + 1) + 
+          " of an image with " + boost::lexical_cast<std::string>(framesCount) + " frames");
       }
       else
       {
@@ -438,12 +460,13 @@ static bool AnswerFrames(OrthancPluginRestOutput* output,
       if (*frame >= fragments->GetNumberOfFragments())
       {
         // TODO A frame is not a fragment, looks like a bug
-        OrthancPlugins::Configuration::LogError("Trying to access frame number " + 
-                                                boost::lexical_cast<std::string>(*frame + 1) + 
-                                                " of an image with " + 
-                                                boost::lexical_cast<std::string>(fragments->GetNumberOfFragments()) + 
-                                                " frames");
-        throw Orthanc::OrthancException(Orthanc::ErrorCode_ParameterOutOfRange);
+        throw Orthanc::OrthancException(
+          Orthanc::ErrorCode_ParameterOutOfRange,
+          "Trying to access frame number " + 
+          boost::lexical_cast<std::string>(*frame + 1) + 
+          " of an image with " + 
+          boost::lexical_cast<std::string>(fragments->GetNumberOfFragments()) + 
+          " frames");
       }
       else
       {
@@ -463,32 +486,30 @@ void RetrieveFrames(OrthancPluginRestOutput* output,
                     const char* url,
                     const OrthancPluginHttpRequest* request)
 {
-  OrthancPluginContext* context = OrthancPlugins::Configuration::GetContext();
-
   gdcm::TransferSyntax targetSyntax(ParseTransferSyntax(request));
 
   std::list<unsigned int> frames;
   ParseFrameList(frames, request);
 
   Json::Value header;
-  std::string uri;
-  OrthancPlugins::MemoryBuffer content(context);
-  if (LocateInstance(output, uri, request) &&
-      content.RestApiGet(uri + "/file", false) &&
-      OrthancPlugins::RestApiGet(header, context, uri + "/header?simplify", false))
+  std::string publicId;
+  OrthancPlugins::MemoryBuffer content;
+  if (LocateInstance(output, publicId, request) &&
+      content.RestApiGet("/instances/" + publicId + "/file", false) &&
+      OrthancPlugins::RestApiGet(header, "/instances/" + publicId + "/header?simplify", false))
   {
     {
-      std::string s = "DICOMweb RetrieveFrames on " + uri + ", frames: ";
+      std::string s = "DICOMweb RetrieveFrames on " + publicId + ", frames: ";
       for (std::list<unsigned int>::const_iterator 
              frame = frames.begin(); frame != frames.end(); ++frame)
       {
         s += boost::lexical_cast<std::string>(*frame + 1) + " ";
       }
 
-      OrthancPlugins::Configuration::LogInfo(s);
+      OrthancPlugins::LogInfo(s);
     }
 
-    std::auto_ptr<OrthancPlugins::ParsedDicomFile> source;
+    std::auto_ptr<OrthancPlugins::GdcmParsedDicomFile> source;
 
     gdcm::TransferSyntax sourceSyntax;
 
@@ -499,7 +520,7 @@ void RetrieveFrames(OrthancPluginRestOutput* output,
     }
     else
     {
-      source.reset(new OrthancPlugins::ParsedDicomFile(content));
+      source.reset(new OrthancPlugins::GdcmParsedDicomFile(content));
       sourceSyntax = source->GetFile().GetHeader().GetDataSetTransferSyntax();
     }
 
@@ -511,7 +532,7 @@ void RetrieveFrames(OrthancPluginRestOutput* output,
 
       if (source.get() == NULL)
       {
-        source.reset(new OrthancPlugins::ParsedDicomFile(content));
+        source.reset(new OrthancPlugins::GdcmParsedDicomFile(content));
       }
 
       AnswerFrames(output, request, *source, targetSyntax, frames);
@@ -521,9 +542,9 @@ void RetrieveFrames(OrthancPluginRestOutput* output,
       // Need to convert the transfer syntax
 
       {
-        OrthancPlugins::Configuration::LogInfo("DICOMweb RetrieveFrames: Transcoding " + uri + 
-                                               " from transfer syntax " + std::string(sourceSyntax.GetString()) + 
-                                               " to " + std::string(targetSyntax.GetString()));
+        OrthancPlugins::LogInfo("DICOMweb RetrieveFrames: Transcoding instance " + publicId + 
+                                " from transfer syntax " + std::string(sourceSyntax.GetString()) + 
+                                " to " + std::string(targetSyntax.GetString()));
       }
 
       gdcm::ImageChangeTransferSyntax change;
@@ -537,15 +558,15 @@ void RetrieveFrames(OrthancPluginRestOutput* output,
       reader.SetStream(stream);
       if (!reader.Read())
       {
-        OrthancPlugins::Configuration::LogError("Cannot decode the image");
-        throw Orthanc::OrthancException(Orthanc::ErrorCode_BadFileFormat);
+        throw Orthanc::OrthancException(Orthanc::ErrorCode_BadFileFormat,
+                                        "Cannot decode the image");
       }
 
       change.SetInput(reader.GetImage());
       if (!change.Change())
       {
-        OrthancPlugins::Configuration::LogError("Cannot change the transfer syntax of the image");
-        throw Orthanc::OrthancException(Orthanc::ErrorCode_InternalError);
+        throw Orthanc::OrthancException(Orthanc::ErrorCode_InternalError,
+                                        "Cannot change the transfer syntax of the image");
       }
 
       gdcm::ImageWriter writer;
@@ -559,7 +580,7 @@ void RetrieveFrames(OrthancPluginRestOutput* output,
         throw Orthanc::OrthancException(Orthanc::ErrorCode_NotEnoughMemory);
       }
 
-      OrthancPlugins::ParsedDicomFile transcoded(ss.str());
+      OrthancPlugins::GdcmParsedDicomFile transcoded(ss.str());
       AnswerFrames(output, request, transcoded, targetSyntax, frames);
     }
   }    
