@@ -21,6 +21,7 @@
 
 #include <gtest/gtest.h>
 #include <boost/lexical_cast.hpp>
+#include <boost/algorithm/string/predicate.hpp>
 
 #include "../Plugin/Configuration.h"
 
@@ -29,6 +30,7 @@ using namespace OrthancPlugins;
 OrthancPluginContext* context_ = NULL;
 
 
+// TODO => Remove this test (now in Orthanc core)
 TEST(ContentType, Parse)
 {
   std::string c;
